import cv2
import numpy as np
from camshell.camshell_core import CamShell


class CamShellVision(CamShell):
    def process_image(self, image: cv2.UMat) -> None:
        lab = cv2.cvtColor(image, cv2.COLOR_BGR2LAB)
        l, a, b = cv2.split(lab)

        # Apply CLAHE to the L-channel to enhance contrast
        clahe = cv2.createCLAHE(clipLimit=2.0, tileGridSize=(8, 8))
        l_clahe = clahe.apply(l)

        # Merge the adjusted L-channel back with the original A and B channels
        lab_clahe = cv2.merge((l_clahe, a, b))

        # Convert back to BGR color space
        enhanced_image = cv2.cvtColor(lab_clahe, cv2.COLOR_LAB2BGR)

        # (Optional) Apply gamma correction to brighten dark spots
        # gamma = 0  # Adjust as needed
        # gamma_lut = np.array(
        #     [pow(x / 255.0, gamma) * 255 for x in range(256)], dtype=np.uint8
        # )
        # gamma_corrected = cv2.LUT(enhanced_image, gamma_lut)

        # Call the parent class's process_image with the enhanced image
        return super().process_image(enhanced_image)