import curses

from camshell.pixshell import PixShell


class XScreen(PixShell):
    """Curses-based screen renderer for 256-color terminals."""

    def __init__(
        self, mono_color: bool = False, screen: curses.window | None = None
    ) -> None:
        super().__init__(mono_color)
        self.screen = screen
        if screen is not None:
            self.init(screen)

    def init(self, screen: curses.window) -> None:
        super().init(screen.getmaxyx()[1] - 1, screen.getmaxyx()[0] - 1)
        self.screen = screen
        curses.start_color()
        self.max_colors = curses.COLORS
        self._init_colors()

    def _init_colors(self) -> None:
        for i in range(1, self.max_colors):
            curses.init_pair(i, i, curses.COLOR_BLACK)

    def display(self) -> None:
        self.screen.clear()
        for y in range(self.height):
            for x, (char, color) in enumerate(self.get_row(y)):
                curs_color = curses.color_pair(color)
                self.screen.addch(y, x, char, curs_color)
        self.screen.refresh()
